# gamechain-py
This library is a Python implementation of the GameChainLobby and GameChain multi-player, Bitcoin Cash (BCH) blockchain-based multi-player game matching and participation framework. It requires Python 3.6 or later.

GameChainLobby and GameChain protocol specifications [are available here](https://github.com/devalbo/gamechain-specs).

